orderBy method
Creates and returns a new Query that's additionally sorted by the specified
field.
The field may be a String representing a single field name or a FieldPath.
After a FieldPath.documentId order by call, you cannot add any more orderBy
calls.
Furthermore, you may not use orderBy on the FieldPath.documentId field when
using startAfterDocument, startAtDocument, endBeforeDocument,
or endAtDocument because the order by clause on the document id
is added by these methods implicitly.
Implementation
@override
Query<Map<String, dynamic>> orderBy(Object field, {bool descending = false}) {
// TODO: implement orderBy
throw UnimplementedError();
}